betty.locale.localizable module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.locale.localizable module

The localizable API allows objects to be localized at the point of use.

class betty.locale.localizable.Localizable

  Bases: `ABC`

  A localizable object.

  Objects of this type can convert themselves to localized strings at the point of use.

  abstract localize(localizer: Localizer) → str

    Localize `self` to a human-readable string.

betty.locale.localizable.call(call: Callable[[Localizer], str]) → Localizable

  Create a new localizable that outputs the callable’s return value.

betty.locale.localizable.format(localizable: Localizable, *format_args: str | Localizable, **format_kwargs: str | Localizable) → Localizable

  Perform string formatting.

  The arguments are identical to those of :py:meth:`str.format`.

betty.locale.localizable.gettext(message: str) → _GettextLocalizable

  Like `gettext.gettext()`.

  Positional arguments are identical to those of `gettext.gettext()`. Keyword arguments are identical to those of :py:met:`str.format`, except that any `betty.locale.Localizable` will be localized before string formatting.

betty.locale.localizable.ngettext(message_singular: str, message_plural: str, n: int) → _GettextLocalizable

  Like `gettext.ngettext()`.

  Positional arguments are identical to those of `gettext.ngettext()`. Keyword arguments are identical to those of :py:met:`str.format`, except that any `betty.locale.Localizable` will be localized before string formatting.

betty.locale.localizable.npgettext(context: str, message_singular: str, message_plural: str, n: int) → _GettextLocalizable

  Like `gettext.npgettext()`.

  Positional arguments are identical to those of `gettext.npgettext()`. Keyword arguments are identical to those of :py:met:`str.format`, except that any `betty.locale.Localizable` will be localized before string formatting.

betty.locale.localizable.pgettext(context: str, message: str) → _GettextLocalizable

  Like `gettext.pgettext()`.

  Positional arguments are identical to those of `gettext.pgettext()`. Keyword arguments are identical to those of :py:met:`str.format`, except that any `betty.locale.Localizable` will be localized before string formatting.

betty.locale.localizable.plain(plain: Any) → Localizable

  Create a new localizable that outputs the given plain text string.

  Keyword arguments are identical to those of :py:met:`str.format`, except that any `betty.locale.Localizable` will be localized before string formatting.